Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Server Migration Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS Server Migration Service - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Server Migration Service

AWS Server Migration Service (service prefix: `sms` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Server Migration Service
- Resource Types Defined by AWS Server Migration Service
- Condition Keys for AWS Server Migration Service

## Actions Defined by AWS Server Migration Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateApp | Create an application configuration to migrate on-premise application onto AWS.. | Write |  |  |
CreateReplicationJob | Create a job to migrate on-premise server onto AWS. | Write |  |  |
DeleteApp | Delete an existing application configuration. | Write |  |  |
DeleteAppLaunchConfiguration | Delete launch configuration for an existing application. | Write |  |  |
DeleteAppReplicationConfiguration | Delete replication configuration for an existing application.. | Write |  |  |
DeleteReplicationJob | Delete an existing job to migrate on-premise server onto AWS. | Write |  |  |
DeleteServerCatalog | Delete the complete list of on-premise servers gathered into AWS. | Write |  |  |
DisassociateConnector | Disassociate a connector that has been associated. | Write |  |  |
GenerateChangeSet | Generate a changeSet for the CloudFormation stack of an application. | Write |  |  |
GenerateTemplate | Generate a CloudFormation template for an existing application. | Write |  |  |
GetApp | Get the configuration and statuses for an existing application. | Read |  |  |
GetAppLaunchConfiguration | Get launch configuration for an existing application. | Read |  |  |
GetAppReplicationConfiguration | Get replication configuration for an existing application. | Read |  |  |
GetConnectors | Get all connectors that have been associated. | Read |  |  |
GetMessages [permission only] | Gets messages from AWS Server Migration Service to Server Migration Connector. | Read |  |  |
GetReplicationJobs | Get all existing jobs to migrate on-premise servers onto AWS. | Read |  |  |
GetReplicationRuns | Get all runs for an existing job. | Read |  |  |
GetServers | Get all servers that have been imported. | Read |  |  |
ImportServerCatalog | Gathers a complete list of on-premise servers. | Write |  |  |
LaunchApp | Create and launch a CloudFormation stack for an existing application. | Write |  |  |
ListApps | Get a list of summaries for existing applications. | List |  |  |
PutAppLaunchConfiguration | Create or update launch configuration for an existing application. | Write |  |  |
PutAppReplicationConfiguration | Create or update replication configuration for an existing application. | Write |  |  |
SendMessage [permission only] | Send message from Server Migration Connector to AWS Server Migration Service. | Write |  |  |
StartAppReplication | Create and start replication jobs for an existing application. | Write |  |  |
StartOnDemandReplicationRun | Start a replication run for an existing replication job. | Write |  |  |
StopAppReplication | Stop and delete replication jobs for an existing application. | Write |  |  |
TerminateApp | Terminate the CloudFormation stack for an existing application. | Write |  |  |
UpdateApp | Update an existing application configuration | Write |  |  |
UpdateReplicationJob | Update an existing job to migrate on-premise server onto AWS. | Write |  |  |

## Resource Types Defined by AWS Server Migration Service

AWS Server Migration Service does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Server Migration Service, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS Server Migration Service

ServerMigrationService has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .